@@ -9,25 +9,27 @@ import java.io.IOException;
  * multiple views of the same column in the base, but note that modifying
  * a cell in one of these will modify it in the other.
  *
- * <p>An <tt>int[]</tt> array, <tt>columnMap</tt>, is used to keep track of
+ * <p>An <code>int[]</code> array, <code>columnMap</code>,
+ * is used to keep track of
  * which columns in this table correspond to which columns in the base table;
- * the <tt>n</tt>'th column in this table corresponds to the 
- * <tt>columnMap[n]</tt>'th column in the base table.
- * The <tt>columnMap</tt> array may contain duplicate entries, but all
- * its entries must be in the range <tt>0..baseTable.getColumnCount()-1</tt>.
- * This table will have <tt>columnMap.length</tt> entries.
+ * the <code>n</code>'th column in this table corresponds to the 
+ * <code>columnMap[n]</code>'th column in the base table.
+ * The <code>columnMap</code> array may contain duplicate entries, but all
+ * its entries must be in the range
+ * <code>0..baseTable.getColumnCount()-1</code>.
+ * This table will have <code>columnMap.length</code> entries.
  *
  * <p>One implementation decision to be made is how to implement the
- * <tt>getRow</tt> methods on this table and on any RowSequence taken
- * out on it.  It could either invoke <tt>getRow</tt> on the base
- * table/sequence, or invoke <tt>getCell</tt> multiple times.
+ * <code>getRow</code> methods on this table and on any RowSequence taken
+ * out on it.  It could either invoke <code>getRow</code> on the base
+ * table/sequence, or invoke <code>getCell</code> multiple times.
  * The performance characteristics are likely to be different for the
  * two, though it's not obvious which will be best.  In general,
  * if this table has the same number of columns (or more) than the
- * base table, then using <tt>getRow</tt> will be better, and if it
- * has many fewer, then <tt>getCell</tt> will be.
+ * base table, then using <code>getRow</code> will be better, and if it
+ * has many fewer, then <code>getCell</code> will be.
  * The user may choose between these behaviours using the 
- * <tt>readRow</tt> parameter in one of the constructors.
+ * <code>readRow</code> parameter in one of the constructors.
  * If the other constructor (which doesn't have this argument) is used
  * then a choice will be made on the basis of the ratio of columns
  * in this table to the ratio of the columns in the base table
@@ -42,42 +44,45 @@ public class ColumnPermutedStarTable extends WrapperStarTable {
     private boolean readRow_;
 
     /**
-     * When <tt>readRow</tt> is not specified explicitly, this gives the
-     * threshold for determining how <tt>getRow</tt> methods are implemented.
+     * When <code>readRow</code> is not specified explicitly, this gives the
+     * threshold for determining how <code>getRow</code> methods
+     * are implemented.
      * If
      * <pre>
      * getColumnCount() / getBaseTable().getColumnCount() &gt; READROW_FRACTION
      * </pre>
-     * then the base <tt>getRow</tt> method is implemented, otherwise
-     * multiple calls of <tt>getCell</tt> are used.
+     * then the base <code>getRow</code> method is implemented, otherwise
+     * multiple calls of <code>getCell</code> are used.
      */
     public static final double READROW_FRACTION = 0.75;
 
     /**
-     * Constructs a new <tt>ColumnPermutedStarTable</tt> 
-     * from a base <tt>StarTable</tt> and a <tt>columnMap</tt> array,
+     * Constructs a new <code>ColumnPermutedStarTable</code> 
+     * from a base <code>StarTable</code> and a <code>columnMap</code> array,
      * making its own decision about how to read rows.
      *
      * @param  baseTable   the table on which this one is based
      * @param  columnMap  array describing where each column of this table
-     *         comes from in <tt>baseTable</tt>
+     *         comes from in <code>baseTable</code>
      */
+    @SuppressWarnings("this-escape")
     public ColumnPermutedStarTable( StarTable baseTable, int[] columnMap ) {
         super( baseTable );
         setColumnMap( columnMap );
     }
 
     /**
-     * Constructs a new <tt>ColumnPermutedStarTable</tt>
-     * from a base <tt>StarTable</tt> and <tt>columnMap</tt> array,
+     * Constructs a new <code>ColumnPermutedStarTable</code>
+     * from a base <code>StarTable</code> and <code>columnMap</code> array,
      * with explicit instruction about how to read rows.
      *
      * @param  baseTable  the table on which this one is based
      * @param  columnMap  array describing where each column of this table
-     *         comes from in <tt>baseTable</tt>
-     * @param  readRow    true if the <tt>readRow</tt> implementations should
-     *         invoke <tt>readRow</tt> on the base table, false if they
-     *         should use <tt>readCell</tt> instead
+     *         comes from in <code>baseTable</code>
+     * @param  readRow    true if the <code>readRow</code>
+     *         implementations should
+     *         invoke <code>readRow</code> on the base table, false if they
+     *         should use <code>readCell</code> instead
      */
     public ColumnPermutedStarTable( StarTable baseTable, int[] columnMap,
                                     boolean readRow ) {
@@ -212,6 +217,7 @@ public class ColumnPermutedStarTable extends WrapperStarTable {
      * @param  data  base RowData
      * @return   output RowData
      */
+    @SuppressWarnings("this-escape")
     private RowData permuteMapper( final RowData data ) {
         return readRow_
              ? new RowData() {
