@@ -7,14 +7,14 @@ import java.util.List;
 /**
  * A random-access StarTable that manages its data in columns.
  * The data in each column
- * is managed by a <tt>ColumnData</tt> object which can be accessed
+ * is managed by a <code>ColumnData</code> object which can be accessed
  * directly using the {@link #getColumnData} method.  Columns can be
  * added and substituted.  If the columns permit it then table cells
  * can be written to as well as read from.
  * <p>
  * Concrete subclasses of this abstract class must implement 
  * {@link #getRowCount}. 
- * If you just need a <tt>ColumnStarTable</tt> with a fixed number of rows
+ * If you just need a <code>ColumnStarTable</code> with a fixed number of rows
  * you can use the static convenience method {@link #makeTableWithRows}.
  *
  * @author   Mark Taylor (Starlink)
@@ -30,13 +30,14 @@ public abstract class ColumnStarTable extends RandomStarTable {
     }
 
     /**
-     * Initialises a <tt>ColumnStarTable</tt> using a template 
-     * <tt>StarTable</tt> to provide per-table metadata.
-     * The newly constructed object will have copies of the <tt>template</tt>'s
-     * name, parameters etc.
+     * Initialises a <code>ColumnStarTable</code> using a template 
+     * <code>StarTable</code> to provide per-table metadata.
+     * The newly constructed object will have
+     * copies of the <code>template</code>'s name, parameters etc.
      *
      * @param   template  the template StarTable
      */
+    @SuppressWarnings("this-escape")
     public ColumnStarTable( StarTable template ) {
         setName( template.getName() );
         setParameters( new ArrayList<DescribedValue>( template
@@ -45,7 +46,7 @@ public abstract class ColumnStarTable extends RandomStarTable {
 
     /**
      * Gets the number of rows in the table (which must be applicable to
-     * all the columns).  Since this is a <tt>RandomStarTable</tt> the
+     * all the columns).  Since this is a <code>RandomStarTable</code> the
      * return value must be non-negative.
      *
      * @return  number of rows
@@ -71,8 +72,9 @@ public abstract class ColumnStarTable extends RandomStarTable {
      * @param  icol  the column index
      * @param  value  the value to store
      * @throws  IOException if an I/O error occurs
-     * @throws  UnsupportedOperationException  if column <tt>icol</tt> is not
-     *          writable (<tt>!getColumnData(icol).isWritable()</tt>);
+     * @throws  UnsupportedOperationException  if column <code>icol</code>
+     *          is not writable
+     *          (<code>!getColumnData(icol).isWritable()</code>);
      */
     public void setCell( long lrow, int icol, Object value )
             throws IOException {
@@ -87,10 +89,10 @@ public abstract class ColumnStarTable extends RandomStarTable {
     }
 
     /**
-     * Returns the <tt>ColumnData</tt> object for a given column.
+     * Returns the <code>ColumnData</code> object for a given column.
      *
      * @param  icol  the index of the column for which the result is required
-     * @return the ColumnData for column <tt>icol</tt>
+     * @return the ColumnData for column <code>icol</code>
      */
     public ColumnData getColumnData( int icol ) {
         return columns_.get( icol );
@@ -117,7 +119,7 @@ public abstract class ColumnStarTable extends RandomStarTable {
     }
 
     /**
-     * Convenience method to return a <tt>ColumnStarTable</tt> 
+     * Convenience method to return a <code>ColumnStarTable</code> 
      * with a fixed number of rows.
      * 
      * @param  nrow  the number of rows this table will have
