@@ -23,6 +23,7 @@ public class EditableColumn extends WrapperColumn {
     /**
      * Constructs a new EditableColumn based on an existing column.
      */
+    @SuppressWarnings("this-escape")
     public EditableColumn( ColumnData base ) {
         super( base );
         base_ = base;
@@ -33,7 +34,7 @@ public class EditableColumn extends WrapperColumn {
     }
 
     /**
-     * Returns <tt>true</tt>.
+     * Returns <code>true</code>.
      *
      * @return  whether cells can be edited.  They can.
      */
@@ -42,7 +43,7 @@ public class EditableColumn extends WrapperColumn {
     }
 
     public Object readValue( long irow ) throws IOException {
-        Long key = new Long( irow );
+        Long key = Long.valueOf( irow );
         return changedEntries_.containsKey( key ) ? changedEntries_.get( key )
                                                   : base_.readValue( irow );
     }
@@ -58,7 +59,7 @@ public class EditableColumn extends WrapperColumn {
                 "Value " + value + " is a " + value.getClass() + " not a " + 
                 getColumnInfo().getContentClass() );
         }
-        Long key = new Long( irow );
+        Long key = Long.valueOf( irow );
         changedEntries_.put( key, value );
     }
 }
