@@ -41,6 +41,14 @@ public class EmptyStarTable extends WrapperStarTable {
     }
 
     public RowSequence getRowSequence() {
-        return new RandomRowSequence( this );
+        return EmptyRowSequence.getInstance();
+    }
+
+    public RowAccess getRowAccess() {
+        return EmptyRowSequence.getInstance();
+    }
+
+    public RowSplittable getRowSplittable() {
+        return EmptyRowSequence.getInstance();
     }
 }
