@@ -32,6 +32,7 @@ import uk.ac.starlink.table.formats.TstTableWriter;
 import uk.ac.starlink.util.BeanConfig;
 import uk.ac.starlink.util.LoadException;
 import uk.ac.starlink.util.Loader;
+import uk.ac.starlink.util.URLUtils;
 
 /**
  * Outputs StarTable objects.
@@ -42,25 +43,22 @@ import uk.ac.starlink.util.Loader;
  * By default, if the corresponding classes are present, the following
  * handlers are installed:
  * <ul>
- * <li> {@link uk.ac.starlink.votable.FitsPlusTableWriter}
- * <li> {@link uk.ac.starlink.fits.FitsTableWriter}
- * <li> {@link uk.ac.starlink.fits.VariableFitsTableWriter}
- * <li> {@link uk.ac.starlink.fits.HealpixFitsTableWriter}
+ * <li> {@link uk.ac.starlink.votable.UnifiedFitsTableWriter}
  * <li> {@link uk.ac.starlink.votable.VOTableWriter}
+ * <li> {@link uk.ac.starlink.fits.HealpixFitsTableWriter}
  * <li> {@link uk.ac.starlink.ecsv.EcsvTableWriter}
  * <li> {@link uk.ac.starlink.parquet.ParquetTableWriter}
- * <li> {@link uk.ac.starlink.feather.FeatherTableWriter}
  * <li> {@link uk.ac.starlink.table.formats.TextTableWriter}
  * <li> {@link uk.ac.starlink.table.formats.AsciiTableWriter}
  * <li> {@link uk.ac.starlink.table.formats.CsvTableWriter}
  * <li> {@link uk.ac.starlink.table.formats.IpacTableWriter}
- * <li> {@link uk.ac.starlink.table.formats.TstTableWriter}
- * <li> {@link uk.ac.starlink.votable.ColFitsPlusTableWriter}
  * <li> {@link uk.ac.starlink.table.formats.HTMLTableWriter}
  * <li> {@link uk.ac.starlink.table.formats.LatexTableWriter}
+ * <li> {@link uk.ac.starlink.table.formats.TstTableWriter}
+ * <li> {@link uk.ac.starlink.feather.FeatherTableWriter}
  * <li> {@link uk.ac.starlink.mirage.MirageTableWriter}
  * </ul>
- * Additionally, any classes named in the <tt>startable.writers</tt>
+ * Additionally, any classes named in the <code>startable.writers</code>
  * system property (as a colon-separated list) which implement the
  * {@link StarTableWriter} interface and have a no-arg constructor will be
  * instantiated and added to this list of handlers.
@@ -74,23 +72,20 @@ public class StarTableOutput {
     private List<StarTableWriter> handlers_;
     private JDBCHandler jdbcHandler_;
     private static String[] defaultHandlerClasses = {
-        "uk.ac.starlink.votable.FitsPlusTableWriter",
-        "uk.ac.starlink.fits.FitsTableWriter",
-        "uk.ac.starlink.fits.VariableFitsTableWriter",
-        "uk.ac.starlink.fits.HealpixFitsTableWriter",
-        "uk.ac.starlink.votable.ColFitsPlusTableWriter",
-        "uk.ac.starlink.fits.ColFitsTableWriter",
+        "uk.ac.starlink.votable.UnifiedFitsTableWriter",
+        "uk.ac.starlink.votable.UnifiedFitsTableWriter$Col",
         "uk.ac.starlink.votable.VOTableWriter",
+        "uk.ac.starlink.fits.HealpixFitsTableWriter",
         "uk.ac.starlink.ecsv.EcsvTableWriter",
         "uk.ac.starlink.parquet.ParquetTableWriter",
-        "uk.ac.starlink.feather.FeatherTableWriter",
         TextTableWriter.class.getName(),
         AsciiTableWriter.class.getName(),
         CsvTableWriter.class.getName(),
         IpacTableWriter.class.getName(),
-        TstTableWriter.class.getName(),
         HTMLTableWriter.class.getName(),
         LatexTableWriter.class.getName(),
+        TstTableWriter.class.getName(),
+        "uk.ac.starlink.feather.FeatherTableWriter",
         "uk.ac.starlink.mirage.MirageTableWriter",
     };
     private static Map<String,String> legacyHandlerMap_ =
@@ -113,6 +108,7 @@ public class StarTableOutput {
     /**
      * Constructs a StarTableOutput with a default list of handlers.
      */
+    @SuppressWarnings("this-escape")
     public StarTableOutput() {
         handlers_ = new ArrayList<StarTableWriter>();
 
@@ -125,7 +121,8 @@ public class StarTableOutput {
                     (Class<? extends StarTableWriter>)
                     Class.forName( className );
 
-                StarTableWriter handler = clazz.newInstance();
+                StarTableWriter handler =
+                    clazz.getDeclaredConstructor().newInstance();
                 handlers_.add( handler );
                 logger.config( "Handler " + handler.getFormatName() +
                                " registered" );
@@ -153,7 +150,7 @@ public class StarTableOutput {
      * table before ones later in the list.  The returned list may be
      * modified to change this object's behaviour.
      *
-     * @return  handlers  a list of <tt>StarTableWriter</tt> objects 
+     * @return  handlers  a list of <code>StarTableWriter</code> objects 
      */
     public List<StarTableWriter> getHandlers() {
         return handlers_;
@@ -164,7 +161,7 @@ public class StarTableOutput {
      * Handlers earlier in the list are given a chance to write the
      * table before ones later in the list.
      *
-     * @param  handlers  an array of <tt>StarTableWriter</tt> objects
+     * @param  handlers  an array of <code>StarTableWriter</code> objects
      */
     public void setHandlers( StarTableWriter[] handlers ) {
         handlers_ =
@@ -172,25 +169,25 @@ public class StarTableOutput {
     }
 
     /**
-     * Writes a <tt>StarTable</tt> object out to some external storage.
+     * Writes a <code>StarTable</code> object out to some external storage.
      * The format in which it is written is determined by some
      * combination of the given output location and a format indicator.
      *
      * @param  startab  the table to output
      * @param  location the location at which to write the new table.
-     *         This may be a filename or URL, including a <tt>jdbc:</tt>
+     *         This may be a filename or URL, including a <code>jdbc:</code>
      *         protocol if suitable JDBC drivers are installed
      * @param  format   a string which indicates in some way what format
      *         should be used for output.  This may be the class name of
-     *         a <tt>StarTableWriter</tt> object (which may or may not be 
-     *         registered with this <tt>StarTableOutput</tt>), or else
+     *         a <code>StarTableWriter</code> object (which may or may not be 
+     *         registered with this <code>StarTableOutput</code>), or else
      *         a string which matches the format name of one of the registered 
-     *         <tt>StarTableWriter</tt>s (first match is used, 
+     *         <code>StarTableWriter</code>s (first match is used, 
      *         case-insensitive, starting substrings OK)
-     *         or <tt>null</tt> or {@link #AUTO_HANDLER} 
+     *         or <code>null</code> or {@link #AUTO_HANDLER} 
      *         to indicate that a handler should be 
-     *         selected based on the value of <tt>location</tt>.
-     *         Ignored for <tt>jdbc:</tt>-protocol locations
+     *         selected based on the value of <code>location</code>.
+     *         Ignored for <code>jdbc:</code>-protocol locations
      * @throws TableFormatException  if no suitable handler is known
      */
     public void writeStarTable( StarTable startab, String location,
@@ -220,7 +217,7 @@ public class StarTableOutput {
     /**
      * Writes a StarTable to an output stream.
      * This convenience method wraps the stream in a BufferedOutputStream
-     * for efficiency and uses the submitted <tt>handler</tt> to perform
+     * for efficiency and uses the submitted <code>handler</code> to perform
      * the write, closing the stream afterwards.
      *
      * @param  startab   table to write
@@ -256,14 +253,15 @@ public class StarTableOutput {
      *          this may be a filename or URL
      * @param  format   a string which indicates in some way what format
      *         should be used for output.  This may be the class name of
-     *         a <tt>MultiStarTableWriter</tt> object (which may or may not be
-     *         registered with this <tt>StarTableOutput</tt>), or else
+     *         a <code>MultiStarTableWriter</code> object
+     *         (which may or may not be registered with this
+     *         <code>StarTableOutput</code>), or else
      *         a string which matches the format name of one of the registered
-     *         <tt>MultiStarTableWriter</tt>s (first match is used,
+     *         <code>MultiStarTableWriter</code>s (first match is used,
      *         case-insensitive, starting substrings OK)
-     *         or <tt>null</tt> or {@link #AUTO_HANDLER}
+     *         or <code>null</code> or {@link #AUTO_HANDLER}
      *         to indicate that a handler should be
-     *         selected based on the value of <tt>location</tt>.
+     *         selected based on the value of <code>location</code>.
      */
     public void writeStarTables( StarTable[] tables, String location,
                                  String format )
@@ -287,7 +285,7 @@ public class StarTableOutput {
     /**
      * Writes an array of StarTables to an output stream.
      * This convenience method wraps the stream in a BufferedOutputStream
-     * for efficiency and uses the submitted <tt>handler</tt> to perform
+     * for efficiency and uses the submitted <code>handler</code> to perform
      * the write, closing the stream afterwards.
      *
      * @param  tables  tables to write
@@ -335,19 +333,19 @@ public class StarTableOutput {
      * passes, a <code>UnrepeatableSequenceException</code> will be thrown.
      *
      * @param  location the location at which to write the new table.
-     *         This may be a filename or URL, including a <tt>jdbc:</tt>
+     *         This may be a filename or URL, including a <code>jdbc:</code>
      *         protocol if suitable JDBC drivers are installed
      * @param  format   a string which indicates in some way what format
      *         should be used for output.  This may be the class name of
-     *         a <tt>StarTableWriter</tt> object (which may or may not be
-     *         registered with this <tt>StarTableOutput</tt>), or else
+     *         a <code>StarTableWriter</code> object (which may or may not be
+     *         registered with this <code>StarTableOutput</code>), or else
      *         a string which matches the format name of one of the registered
-     *         <tt>StarTableWriter</tt>s (first match is used,
+     *         <code>StarTableWriter</code>s (first match is used,
      *         case-insensitive, starting substrings OK)
-     *         or <tt>null</tt> or {@link #AUTO_HANDLER}
+     *         or <code>null</code> or {@link #AUTO_HANDLER}
      *         to indicate that a handler should be
-     *         selected based on the value of <tt>location</tt>.
-     *         Ignored for <tt>jdbc:</tt>-protocol locations
+     *         selected based on the value of <code>location</code>.
+     *         Ignored for <code>jdbc:</code>-protocol locations
      * @return  sink whose data will be written to a new table
      */
     public TableSink createOutputSink( final String location,
@@ -361,15 +359,15 @@ public class StarTableOutput {
 
     /**
      * Returns an output stream which points to a given location.
-     * Typically <tt>location</tt> is a filename and a corresponding
-     * <tt>FileOutputStream</tt> is returned, but there may be other
+     * Typically <code>location</code> is a filename and a corresponding
+     * <code>FileOutputStream</code> is returned, but there may be other
      * possibilities.  The stream returned by this method will not
      * in general be buffered; for high performance writes, wrapping it
      * in a {@link java.io.BufferedOutputStream} may be a good idea.
      *
      * @param   location  name of destination
-     * @return   output stream which writes to <tt>location</tt>
-     * @throws  IOException  if no stream pointing to <tt>location</tt>
+     * @return   output stream which writes to <code>location</code>
+     * @throws  IOException  if no stream pointing to <code>location</code>
      *          can be opened
      */
     public OutputStream getOutputStream( String location ) throws IOException {
@@ -388,7 +386,7 @@ public class StarTableOutput {
 
         /* Try to interpret it as a URL. */
         try {
-            URL url = new URL( location );
+            URL url = URLUtils.newURL( location );
             URLConnection uconn = url.openConnection();
             uconn.setDoInput( false );
             uconn.setDoOutput( true );
@@ -430,10 +428,10 @@ public class StarTableOutput {
      *
      * @param  format  a string which indicates in some way what format
      *         should be used for output.  This may be the class name of
-     *         a <tt>StarTableWriter</tt> object (which may or may not be
-     *         registered with this <tt>StarTableOutput</tt>), or else
+     *         a <code>StarTableWriter</code> object (which may or may not be
+     *         registered with this <code>StarTableOutput</code>), or else
      *         a string which matches the format name of one of the registered
-     *         <tt>StarTableWriter</tt>s (first match is used,
+     *         <code>StarTableWriter</code>s (first match is used,
      *         case-insensitive, starting substrings OK).
      * @throws TableFormatException  if no handler suitable for the arguments
      *         can be found
@@ -466,9 +464,16 @@ public class StarTableOutput {
         }
 
         /* Otherwise, try to create a handler based on the given name,
-         * which may be a handler name or a StarTableWriter classname,
-         * and configure it if so required. */
+         * which may be a handler name or a StarTableWriter classname. */
         StarTableWriter handler = createNamedHandler( fname );
+
+        /* Hack to maintain backward compatibility with some variant handlers
+         * available pre-STIL4. */
+        if ( handler == null ) {
+            handler = createLegacyHandler( fname );
+        }
+
+        /* Configure the handler if so required. */
         if ( handler != null ) {
             try {
                 config.configBean( handler );
@@ -480,13 +485,6 @@ public class StarTableOutput {
             return handler;
         }
 
-        /* Hack to maintain backward compatibility with some variant handlers
-         * available pre-STIL4. */
-        StarTableWriter legHandler = getLegacyHandler( fname );
-        if ( legHandler != null ) {
-            return legHandler;
-        }
-
         /* No luck - throw an exception. */
         throw new TableFormatException( "No handler for table format \"" +
                                         format + "\"" );
@@ -511,7 +509,7 @@ public class StarTableOutput {
                 Class<? extends StarTableWriter> hclazz = handler.getClass();
                 StarTableWriter handler1;
                 try {
-                    handler1 = hclazz.newInstance();
+                    handler1 = hclazz.getDeclaredConstructor().newInstance();
                 }
                 catch ( ReflectiveOperationException e ) {
                     throw new TableFormatException( "Can't instantiate class "
@@ -536,7 +534,7 @@ public class StarTableOutput {
             Class<? extends StarTableWriter> hclazz =
                 clazz.asSubclass( StarTableWriter.class );
             try {
-                return hclazz.newInstance();
+                return hclazz.getDeclaredConstructor().newInstance();
             }
             catch ( ReflectiveOperationException e ) {
                 throw new TableFormatException( "Can't instantiate class "
@@ -557,15 +555,15 @@ public class StarTableOutput {
      *
      * @param  format   a string which indicates in some way what format
      *         should be used for output.  This may be the class name of
-     *         a <tt>StarTableWriter</tt> object (which may or may not be
-     *         registered with this <tt>StarTableOutput</tt>), or else
+     *         a <code>StarTableWriter</code> object (which may or may not be
+     *         registered with this <code>StarTableOutput</code>), or else
      *         a string which matches the format name of one of the registered
-     *         <tt>StarTableWriter</tt>s (first match is used,
+     *         <code>StarTableWriter</code>s (first match is used,
      *         case-insensitive, starting substrings OK)
-     *         or <tt>null</tt> to indicate that a handler should be
-     *         selected based on the value of <tt>location</tt>.
+     *         or <code>null</code> to indicate that a handler should be
+     *         selected based on the value of <code>location</code>.
      * @param  location  destination of the table to be written.
-     *         If <tt>format</tt> is null, the value of this will be used
+     *         If <code>format</code> is null, the value of this will be used
      *         to try to determine which handler to use, typically on the
      *         basis of filename extension
      * @throws TableFormatException  if no handler suitable for the arguments
@@ -608,7 +606,7 @@ public class StarTableOutput {
     /**
      * Returns a list of the format strings which are defined by the
      * handlers registered with this object.  The elements of the returned
-     * list can be passed as the <tt>format</tt> argument to the 
+     * list can be passed as the <code>format</code> argument to the 
      * {@link #writeStarTable} method.
      */
     public List<String> getKnownFormats() {
@@ -644,7 +642,7 @@ public class StarTableOutput {
     }
 
     /**
-     * Returns a <tt>Transferable</tt> object associated with a given
+     * Returns a <code>Transferable</code> object associated with a given
      * StarTable, for use at the drag end of a drag and drop operation.
      *
      * @param  startab  the table which is to be dragged
@@ -699,7 +697,7 @@ public class StarTableOutput {
      * @return   handler, or null if name does not correspond to a known
      *           legacy name
      */
-    private StarTableWriter getLegacyHandler( String name )
+    private StarTableWriter createLegacyHandler( String name )
             throws TableFormatException {
         for ( Map.Entry<String,String> entry : legacyHandlerMap_.entrySet() ) {
             if ( entry.getKey().startsWith( name ) ) {
@@ -743,6 +741,11 @@ public class StarTableOutput {
                  "votable(format=BINARY2,inline=false)" );
         map.put( "votable-fits-inline",
                  "votable(format=FITS,inline=true)" );
+        map.put( "fits-plus", "fits" );
+        map.put( "fits-basic", "fits(primary=basic)" );
+        map.put( "fits-var", "fits(primary=basic,var=true)" );
+        map.put( "colfits-plus", "fits(col=true)" );
+        map.put( "colfits-basic", "fits(col=true,primary=basic)" );
         map.put( "ecsv-space", "ecsv(delimiter=space)" );
         map.put( "ecsv-comma", "ecsv(delimiter=comma)" );
         map.put( "csv-noheader", "csv(header=false)" );
