@@ -12,6 +12,7 @@ import java.util.Collection;
 import java.util.Iterator;
 import java.util.List;
 import java.util.function.LongSupplier;
+import java.util.function.ToIntFunction;
 import java.util.zip.Adler32;
 import java.util.zip.Checksum;
 import uk.ac.starlink.table.StarTableOutput;
@@ -76,6 +77,16 @@ public class Tables {
                               "Indicator of query status; "
                             + "anything other than OK means something wrong" );
 
+    /**
+     * A user-directed XML string documenting the behaviour of the
+     * {@link #parseCount} method.
+     * This string starts " may be given as " and ends with a full stop.
+     */
+    public static final String PARSE_COUNT_MAY_BE_GIVEN =
+        " may be given as a plain integer (<code>1000</code>),\n" +
+        "or with embedded underscores (<code>1_000</code>),\n" +
+        "or in exponential format (<code>1e3</code>).";
+
     /**
      * ValueInfo representing Right Ascension. 
      * The units are radians and it is non-nullable.
@@ -99,6 +110,12 @@ public class Tables {
         DEC_INFO.setUCD( "POS_EQ_DEC" );
     }
 
+    /**
+     * Private constructor prevents instantiation.
+     */
+    private Tables() {
+    }
+
     /**
      * Returns a table based on a given table and guaranteed to have 
      * random access.  If the original table <code>stab</code> has random
@@ -273,10 +290,14 @@ public class Tables {
         long lrow = 0L;
         RowAccess racc = isRandom ? table.getRowAccess() : null;
         RowSplittable rsplit = table.getRowSplittable();
+        RowSequence rseq2 = table.getRowSequence();
         while ( rseq.next() ) {
+            boolean isEven = lrow % 2 == 0;
             assertTrue( rsplit.next() );
+            assertTrue( rseq2.next() );
             Object[] row = rseq.getRow();
             Object[] rowSplit = rsplit.getRow(); 
+            Object[] row2 = isEven ? rseq2.getRow() : null;
             for ( int icol = 0; icol < ncol; icol++ ) {
 
                 /* Check that elements got in different ways look the same. */
@@ -287,6 +308,7 @@ public class Tables {
                 Object val4 = null;
                 Object val5 = rowSplit[ icol ];
                 Object val6 = rsplit.getCell( icol );
+                Object val7 = isEven ? row2[ icol ] : null;
                 if ( isRandom ) {
                     val3 = table.getCell( lrow, icol );
                     racc.setRowIndex( lrow );
@@ -302,6 +324,9 @@ public class Tables {
                         assertTrue( val3 == null );
                         assertTrue( val4 == null );
                     }
+                    if ( isEven ) {
+                        assertTrue( val7 == null );
+                    }
                 }
                 else {
                     ColumnInfo cinfo = colinfos[ icol ];
@@ -313,13 +338,18 @@ public class Tables {
                     assertTrue( s1.equals( cinfo
                                           .formatValue( val6, formatChars ) ) );
                     if ( isRandom ) {
-                        assertTrue( s1.equals( colinfos[ icol ]
+                        assertTrue( s1.equals( cinfo
                                               .formatValue( val3,
                                                             formatChars ) ) );
-                        assertTrue( s1.equals( colinfos[ icol ]
+                        assertTrue( s1.equals( cinfo
                                               .formatValue( val4,
                                                             formatChars ) ) );
                     }
+                    if ( isEven ) {
+                        assertTrue( s1.equals( cinfo
+                                              .formatValue( val7,
+                                                            formatChars ) ) );
+                    }
                 }
 
                 /* If the cell is an array, check it's the right shape. */
@@ -398,33 +428,72 @@ public class Tables {
      */
     public static int checksumData( StarTable table ) throws IOException {
         Checksum checksum = new Adler32();
-        try ( RowSequence rseq = table.getRowSequence() ) {
-            checksumData( rseq, checksum );
-        }
+        checksumData( table, checksum );
         return (int) checksum.getValue();
     }
 
     /**
      * Feeds the data from a row sequence to a supplied checksum accumulator.
      *
-     * @param  rseq  row sequence containing data
+     * @param  table  table containing data
      * @param  checksum   checksum accumulator
      * @return   number of rows checksummed
      *           (note this is <em>not</em> the checksum value)
      */
-    public static long checksumData( RowSequence rseq, Checksum checksum )
+    public static long checksumData( StarTable table, Checksum checksum )
             throws IOException {
         long lrow = 0;
-        while ( rseq.next() ) {
-            Object[] row = rseq.getRow();
-            for ( Object cell : row ) {
-                int hash = isBlank( cell ) ? -654321 : cell.hashCode();
-                checksum.update( (byte) ( hash >>> 24 ) );
-                checksum.update( (byte) ( hash >>> 16 ) );
-                checksum.update( (byte) ( hash >>>  8 ) );
-                checksum.update( (byte) ( hash >>>  0 ) );
+        int ncol = table.getColumnCount();
+        @SuppressWarnings("unchecked")
+        ToIntFunction<Object>[] hashers =
+            (ToIntFunction<Object>[]) new ToIntFunction<?>[ ncol ];
+        for ( int ic = 0; ic < ncol; ic++ ) {
+            final ToIntFunction<Object> hasher;
+            Class<?> clazz = table.getColumnInfo( ic ).getContentClass();
+            if ( clazz == boolean[].class ) {
+                hasher = a -> Arrays.hashCode( (boolean[]) a );
+            }
+            else if ( clazz == byte[].class ) {
+                hasher = a -> Arrays.hashCode( (byte[]) a );
+            }
+            else if ( clazz == short[].class ) {
+                hasher = a -> Arrays.hashCode( (short[]) a );
+            }
+            else if ( clazz == int[].class ) {
+                hasher = a -> Arrays.hashCode( (int[]) a );
+            }
+            else if ( clazz == long[].class ) {
+                hasher = a -> Arrays.hashCode( (long[]) a );
+            }
+            else if ( clazz == char[].class ) {
+                hasher = a -> Arrays.hashCode( (char[]) a );
+            }
+            else if ( clazz == float[].class ) {
+                hasher = a -> Arrays.hashCode( (float[]) a );
+            }
+            else if ( clazz == double[].class ) {
+                hasher = a -> Arrays.hashCode( (double[]) a );
+            }
+            else {
+                hasher = a -> a.hashCode();
+            }
+            hashers[ ic ] = hasher;
+        }
+        try ( RowSequence rseq = table.getRowSequence() ) {
+            while ( rseq.next() ) {
+                Object[] row = rseq.getRow();
+                for ( int ic = 0; ic < ncol; ic++ ) {
+                    Object cell = row[ ic ];
+                    int hash = isBlank( cell )
+                             ? -654321
+                             : hashers[ ic ].applyAsInt( cell );
+                    checksum.update( (byte) ( hash >>> 24 ) );
+                    checksum.update( (byte) ( hash >>> 16 ) );
+                    checksum.update( (byte) ( hash >>>  8 ) );
+                    checksum.update( (byte) ( hash >>>  0 ) );
+                }
+                lrow++;
             }
-            lrow++;
         }
         return lrow;
     }
@@ -859,6 +928,44 @@ public class Tables {
         }
     }
 
+    /**
+     * Interprets a string as a non-negative long integer.
+     * This mostly just parses the supplied string as an integer,
+     * but it will also accept embedded underscores (like 1_000_000),
+     * suitable exponential notation (like 1e6),
+     * and hexadecimal (like 0x400).
+     *
+     * @see   #PARSE_COUNT_MAY_BE_GIVEN
+     * @param  countTxt  textual representation of integer
+     * @return   non-negative integer value
+     * @throws  NumberFormatException if it can't be interpreted as a
+     *          non-negative integer
+     */
+    public static long parseCount( String countTxt ) {
+        countTxt = countTxt.trim();
+        if ( countTxt.startsWith( "0x" ) ) {
+            return Long.parseLong( countTxt.substring( 2 )
+                                           .replaceAll( "_", "" ),
+                                   16 );
+        }
+        else if ( countTxt.matches( "[0-9]+" ) ) {
+            return Long.parseLong( countTxt );
+        }
+        else if ( countTxt.matches( "[0-9_]+" ) ) {
+            return Long.parseLong( countTxt.replaceAll( "_", "" ) );
+        }
+        else if ( countTxt.matches( "[0-9.]+[eE][+]?[0-9]+" ) ) {
+            double d = Double.parseDouble( countTxt );
+            long l = (long) d;
+            if ( l == d ) {
+                return l;
+            }
+        }
+        String msg = "Can't be interpreted as non-negative integer: "
+                   + countTxt;
+        throw new NumberFormatException( msg );
+    }
+
     /**
      * Implements assertion semantics.
      * This differs from the <code>assert</code>
