@@ -75,6 +75,9 @@ public class TestTableScheme implements TableScheme, Documented {
             "If <code>&lt;opts&gt;</code> and/or <code>&lt;nrow&gt;</code>",
             "are omitted, some default values are used.",
             "</p>",
+            "<p>The <code>&lt;nrow&gt;</code> argument",
+            Tables.PARSE_COUNT_MAY_BE_GIVEN,
+            "</p>",
         "" );
     }
 
@@ -83,10 +86,10 @@ public class TestTableScheme implements TableScheme, Documented {
         if ( args.length > 2 ) {
             throw new TableFormatException( "Too many args" );
         }
-        final int nrow;
+        final long nrow;
         try {
             nrow = args.length > 0 && args[ 0 ].trim().length() > 0
-                 ? Integer.parseInt( args[ 0 ].trim() )
+                 ? Tables.parseCount( args[ 0 ] )
                  : DFLT_NROW;
         }
         catch ( NumberFormatException e ) {
