@@ -75,6 +75,7 @@ public abstract class TableSaveChooser extends JPanel {
      * @param  sto  output marshaller
      * @param  saveDialogs  array of save dialogues to use
      */
+    @SuppressWarnings("this-escape")
     public TableSaveChooser( StarTableOutput sto,
                              TableSaveDialog[] saveDialogs ) {
         super( new BorderLayout() );
@@ -470,8 +471,10 @@ public abstract class TableSaveChooser extends JPanel {
      */
     public static String[] getExtraWriterNames( boolean multi ) {
         List<String> list = new ArrayList<>();
-        list.add( "votable(format=BINARY)" );
-        list.add( "votable(format=BINARY2)" );
+        list.add( "fits-basic" );
+        list.add( "colfits-basic" );
+        list.add( "votable(format=binary2)" );
+        list.add( "fits(primary=votable,var=true)" );
         if ( ! multi ) {
             list.add( "csv(header=false)" );
             list.add( "ecsv(delimiter=comma)" );
@@ -495,7 +498,7 @@ public abstract class TableSaveChooser extends JPanel {
                 new uk.ac.starlink.table.ColumnInfo( "index", Integer.class,
                                                      null ) ) {
                     public Object readValue( long irow ) {
-                        return new Integer( (int) ( irow + 1 ) );
+                        return Integer.valueOf( (int) ( irow + 1 ) );
                     }
                 } );
         new TableSaveChooser() {
