@@ -51,6 +51,7 @@ public class JDBCFormatter {
      * @param  conn  JDBC connection
      * @param  table   input table
      */
+    @SuppressWarnings("this-escape")
     public JDBCFormatter( Connection conn, StarTable table )
             throws SQLException, IOException {
         conn_ = conn;
@@ -325,17 +326,17 @@ public class JDBCFormatter {
      * @return  connection-specific type name
      */
     public String typeName( int sqlType ) throws SQLException {
-        return typeNameMap_.get( new Integer( sqlType ) );
+        return typeNameMap_.get( Integer.valueOf( sqlType ) );
     }
 
     /**
      * Returns a mapping of Type id to SQL type name.  The map key is
      * an Integer object with the value of the corresponding 
      * {@link java.sql.Types} constant and the value is a string which
-     * <tt>conn</tt> will understand.
+     * <code>conn</code> will understand.
      *
      * @param  conn  the connection to work out the mapping for
-     * @return   a new type id-&gt;name mapping for <tt>conn</tt>
+     * @return   a new type id-&gt;name mapping for <code>conn</code>
      */
     private static Map<Integer,String> makeTypesMap( Connection conn )
             throws SQLException {
@@ -344,20 +345,20 @@ public class JDBCFormatter {
         while ( typeInfos.next() ) {
             String name = typeInfos.getString( "TYPE_NAME" );
             int id = (int) typeInfos.getShort( "DATA_TYPE" );
-            Integer key = new Integer( id );
+            Integer key = Integer.valueOf( id );
             if ( ! types.containsKey( key ) ) {
                 types.put( key, name );
             }
         }
         typeInfos.close();
-        if ( ! types.containsKey( new Integer( Types.NULL ) ) ) {
-            types.put( new Integer( Types.NULL ), "NULL" );
+        if ( ! types.containsKey( Integer.valueOf( Types.NULL ) ) ) {
+            types.put( Integer.valueOf( Types.NULL ), "NULL" );
         }
 
         /* Hack for PostgreSQL for which the above procedure results in
          * "text" instead of "varchar" for the Types.VARCHAR type
          * (driver is at fault I'd say, should report varchar before text). */
-        types.put( new Integer( Types.VARCHAR ), "VARCHAR" );
+        types.put( Integer.valueOf( Types.VARCHAR ), "VARCHAR" );
 
         /* Hack for DBMSs which don't return the right types in other ways. */
         setTypeFallback( types, Types.FLOAT, Types.REAL );
@@ -371,9 +372,9 @@ public class JDBCFormatter {
     }
 
     /**
-     * Doctors a type map by adding an entry for a given type <tt>req</tt> 
-     * with a copy of an existing one <tt>fallback</tt>, if the map
-     * doesn't contain <tt>req</tt> in the first place.
+     * Doctors a type map by adding an entry for a given type <code>req</code> 
+     * with a copy of an existing one <code>fallback</code>, if the map
+     * doesn't contain <code>req</code> in the first place.
      *
      * @param  types  type -> name mapping
      * @param  req   required type code
@@ -381,8 +382,8 @@ public class JDBCFormatter {
      */
     private static <V> void setTypeFallback( Map<Integer,V> types,
                                              int req, int fallback ) {
-        Integer reqKey = new Integer( req );
-        Integer fallbackKey = new Integer( fallback );
+        Integer reqKey = Integer.valueOf( req );
+        Integer fallbackKey = Integer.valueOf( fallback );
         if ( ! types.containsKey( reqKey ) &&
              types.containsKey( fallbackKey ) ) {
             types.put( reqKey, types.get( fallbackKey ) );
@@ -395,7 +396,7 @@ public class JDBCFormatter {
      * @param  name  initial column name
      * @param  maxLeng  maximum name length; 0 means no limit
      * @param  idType   type of identifier being quoted, used in log messages
-     * @return   fixed column name (may be the same as <tt>name</tt>)
+     * @return   fixed column name (may be the same as <code>name</code>)
      */
     private String fixName( String name, int maxLeng, String idtype ) {
         final String name0 = name;
