@@ -89,4 +89,14 @@ public class SequentialResultSetStarTable extends AbstractStarTable {
             return rseq;
         }
     }
+
+    @Override
+    public void close() throws IOException {
+        try {
+            srset_.getResultSet().close();
+        }
+        catch ( SQLException e ) {
+            throw new IOException( "SQL Error", e );
+        }
+    }
 }
