@@ -13,6 +13,7 @@ import uk.ac.starlink.table.RowStore;
 import uk.ac.starlink.table.StarTable;
 import uk.ac.starlink.table.TableFormatException;
 import uk.ac.starlink.table.WrapperStarTable;
+import uk.ac.starlink.util.Cleaner;
 import uk.ac.starlink.util.DataBufferedOutputStream;
 import uk.ac.starlink.util.IntList;
 
@@ -47,9 +48,11 @@ public class ByteStoreRowStore implements RowStore {
      *
      * @param  byteStore  storage container used by this row store
      */
+    @SuppressWarnings("this-escape")
     public ByteStoreRowStore( ByteStore byteStore ) {
         byteStore_ = byteStore;
         out_ = new DataBufferedOutputStream( byteStore.getOutputStream() );
+        Cleaner.getInstance().register( this, new CleanAction( byteStore ) );
     }
 
     /**
@@ -154,15 +157,6 @@ public class ByteStoreRowStore implements RowStore {
         return storedTable_;
     }
 
-    protected void finalize() throws Throwable {
-        try {
-            byteStore_.close();
-        }
-        finally {
-            super.finalize();
-        }
-    }
-
     /**
      * Returns the offsets object.  This package-private method is only
      * intended for testing.
@@ -305,4 +299,17 @@ public class ByteStoreRowStore implements RowStore {
                   .createAccess( NioByteStoreAccess.copyBuffers( bbufs_ ) );
         }
     }
+
+    /**
+     * Runnable that cleans up when this row store becomes unreachable.
+     */
+    private static class CleanAction implements Runnable {
+        private final ByteStore bstore_;
+        CleanAction( ByteStore bstore ) {
+            bstore_ = bstore;
+        }
+        public void run() {
+            bstore_.close();
+        }
+    }
 }
